==> haskell-graphite-0.10.0.1-350.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-graphite.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 graphite
version:              0.10.0.1
visibility:           public
id:                   graphite-0.10.0.1-K4IiTnoBPHGFXEn0TXwR9e
key:                  graphite-0.10.0.1-K4IiTnoBPHGFXEn0TXwR9e
license:              BSD-3-Clause
copyright:            2017 Daniel Campoverde
maintainer:           alx@sillybytes.net
author:               Daniel Campoverde
homepage:             https://github.com/alx741/graphite#readme
synopsis:             Graphs and networks library
description:          Represent, analyze and visualize graphs
category:             Data Structures, Graphs
abi:                  636193a2b8f4c979ca1edb0b99c5bf8b
exposed:              True
exposed-modules:
    Data.Graph.Connectivity Data.Graph.DGraph
    Data.Graph.DGraph.DegreeSequence Data.Graph.Generation
    Data.Graph.Morphisms Data.Graph.Read Data.Graph.Traversal
    Data.Graph.Types Data.Graph.UGraph Data.Graph.UGraph.DegreeSequence
    Data.Graph.Visualize

hidden-modules:       Data.Graph.Internal
import-dirs:          /usr/lib/ghc-9.6.6/site-local/graphite-0.10.0.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/graphite-0.10.0.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/graphite-0.10.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-graphite
hs-libraries:         HSgraphite-0.10.0.1-K4IiTnoBPHGFXEn0TXwR9e
depends:
    QuickCheck-2.15.0.1-DMgRmI5QzBCFdvvi5liF0L base-4.18.2.1
    bytestring-0.11.5.3 cassava-0.5.4.1-I5H7lXHpRMwDMqqRDQwXhI
    containers-0.6.7 deepseq-1.4.8.1
    graphviz-2999.20.2.1-EbSaNwTLrlN5QzzC0J6dQ5
    hashable-1.4.7.0-DKTv0aQgcZmBEMi2BPTV4Z process-1.6.19.0
    random-1.2.1.3-6SxnlPLCqt06GlpnYLfwZm text-2.0.2
    unordered-containers-0.2.20.1-50qrTxmoJy9AxZ7OdMnycu
    vector-0.13.2.0-L5lYsWFgdBEAgjlr9nnpMP

haddock-interfaces:   /usr/share/doc/haskell-graphite/html/graphite.haddock
haddock-html:         /usr/share/doc/haskell-graphite/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-graphite-0.10.0.1-351-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-graphite.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 graphite
version:              0.10.0.1
visibility:           public
id:                   graphite-0.10.0.1-9Xh2FWJ3y9YD1DhswiAB7j
key:                  graphite-0.10.0.1-9Xh2FWJ3y9YD1DhswiAB7j
license:              BSD-3-Clause
copyright:            2017 Daniel Campoverde
maintainer:           alx@sillybytes.net
author:               Daniel Campoverde
homepage:             https://github.com/alx741/graphite#readme
synopsis:             Graphs and networks library
description:          Represent, analyze and visualize graphs
category:             Data Structures, Graphs
abi:                  f752ee35752696075eca7ea8673ad1b7
exposed:              True
exposed-modules:
    Data.Graph.Connectivity Data.Graph.DGraph
    Data.Graph.DGraph.DegreeSequence Data.Graph.Generation
    Data.Graph.Morphisms Data.Graph.Read Data.Graph.Traversal
    Data.Graph.Types Data.Graph.UGraph Data.Graph.UGraph.DegreeSequence
    Data.Graph.Visualize

hidden-modules:       Data.Graph.Internal
import-dirs:          /usr/lib/ghc-9.6.6/site-local/graphite-0.10.0.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/graphite-0.10.0.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/graphite-0.10.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-graphite
hs-libraries:         HSgraphite-0.10.0.1-9Xh2FWJ3y9YD1DhswiAB7j
depends:
    QuickCheck-2.15.0.1-1xFq7rzYyJMIIsLto0YgsS base-4.18.2.1
    bytestring-0.11.5.3 cassava-0.5.4.1-1CM8h0noLla7Uv16d8t4LK
    containers-0.6.7 deepseq-1.4.8.1
    graphviz-2999.20.2.1-HAKN3c7Sqcc46OE3rqtSEv
    hashable-1.4.7.0-1GSULm1uRgQBgX6mu6tvYD process-1.6.19.0
    random-1.2.1.3-LIVoFEqTBeMDojO1AYDBLj text-2.0.2
    unordered-containers-0.2.20.1-L0jiELAFLwP1g4FZscm3B5
    vector-0.13.2.0-eGaPlIkScLKlfBYQuI3vH

haddock-interfaces:   /usr/share/doc/haskell-graphite/html/graphite.haddock
haddock-html:         /usr/share/doc/haskell-graphite/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
